@@ -10,11 +10,14 @@ from frontengine.utils.multi_language.language_wrapper import language_wrapper
 
 class GifWidget(QWidget):
 
-    def __init__(self, gif_image_path: str):
+    def __init__(self, gif_image_path: str, draw_location_x: int = 0, draw_location_y: int = 0):
         super().__init__()
+        self.draw_location_x = draw_location_x
+        self.draw_location_y = draw_location_y
         self.opacity: float = 0.2
         self.speed: int = 100
         self.setAttribute(Qt.WidgetAttribute.WA_TranslucentBackground)
+        self.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         self.gif_label: QLabel = QLabel()
         self.gif_label.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.movie: QMovie = QMovie()
@@ -25,6 +28,7 @@ class GifWidget(QWidget):
             self.movie.frameChanged.connect(self.repaint)
             self.gif_label.setMovie(self.movie)
             self.movie.start()
+            self.resize(self.movie.frameRect().size())
         else:
             message_box: QMessageBox = QMessageBox(self)
             message_box.setText(
@@ -60,7 +64,7 @@ class GifWidget(QWidget):
         painter.setOpacity(self.opacity)
         painter.drawPixmap(
             QRect(
-                self.x(), self.y(), self.width(), self.height()
+                self.draw_location_x, self.draw_location_y, self.width(), self.height()
             ),
             current_gif_frame
         )
